# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mira',
 'mira.classifiers',
 'mira.core',
 'mira.core.protos',
 'mira.datasets',
 'mira.detectors',
 'mira.detectors.assets.serve',
 'mira.detectors.experimental',
 'mira.thirdparty.albumentations',
 'mira.thirdparty.albumentations.albumentations',
 'mira.thirdparty.albumentations.albumentations.augmentations',
 'mira.thirdparty.albumentations.albumentations.augmentations.crops',
 'mira.thirdparty.albumentations.albumentations.augmentations.geometric',
 'mira.thirdparty.albumentations.albumentations.core',
 'mira.thirdparty.albumentations.albumentations.imgaug',
 'mira.thirdparty.albumentations.albumentations.pytorch',
 'mira.thirdparty.albumentations.benchmark',
 'mira.thirdparty.albumentations.docs',
 'mira.thirdparty.albumentations.tests',
 'mira.thirdparty.albumentations.tools',
 'mira.thirdparty.clip',
 'mira.thirdparty.clip.clip',
 'mira.thirdparty.clip.tests',
 'mira.thirdparty.smp',
 'mira.thirdparty.smp.docs',
 'mira.thirdparty.smp.misc',
 'mira.thirdparty.smp.segmentation_models_pytorch',
 'mira.thirdparty.smp.segmentation_models_pytorch.base',
 'mira.thirdparty.smp.segmentation_models_pytorch.datasets',
 'mira.thirdparty.smp.segmentation_models_pytorch.decoders',
 'mira.thirdparty.smp.segmentation_models_pytorch.decoders.deeplabv3',
 'mira.thirdparty.smp.segmentation_models_pytorch.decoders.fpn',
 'mira.thirdparty.smp.segmentation_models_pytorch.decoders.linknet',
 'mira.thirdparty.smp.segmentation_models_pytorch.decoders.manet',
 'mira.thirdparty.smp.segmentation_models_pytorch.decoders.pan',
 'mira.thirdparty.smp.segmentation_models_pytorch.decoders.pspnet',
 'mira.thirdparty.smp.segmentation_models_pytorch.decoders.unet',
 'mira.thirdparty.smp.segmentation_models_pytorch.decoders.unetplusplus',
 'mira.thirdparty.smp.segmentation_models_pytorch.encoders',
 'mira.thirdparty.smp.segmentation_models_pytorch.losses',
 'mira.thirdparty.smp.segmentation_models_pytorch.metrics',
 'mira.thirdparty.smp.segmentation_models_pytorch.utils',
 'mira.thirdparty.smp.tests']

package_data = \
{'': ['*'],
 'mira.datasets': ['assets/*'],
 'mira.thirdparty.albumentations': ['.github/ISSUE_TEMPLATE/*',
                                    '.github/workflows/*',
                                    'conda.recipe/*'],
 'mira.thirdparty.albumentations.docs': ['_templates/*',
                                         'api/*',
                                         'augs_overview/*'],
 'mira.thirdparty.albumentations.tests': ['files/*'],
 'mira.thirdparty.clip': ['.github/workflows/*', 'data/*', 'notebooks/*'],
 'mira.thirdparty.smp': ['.github/*',
                         '.github/workflows/*',
                         'docker/*',
                         'examples/*',
                         'pics/*']}

install_requires = \
['matplotlib', 'numpy', 'pandas', 'protobuf', 'tqdm', 'validators']

extras_require = \
{'classifiers': ['ftfy', 'regex'],
 'detectors': ['scikit-image',
               'timm',
               'pretrainedmodels',
               'efficientnet_pytorch']}

setup_kwargs = {
    'name': 'mira',
    'version': '0.9.1',
    'description': 'A package for simplifying object detection',
    'long_description': '# mira ![CI Status](https://github.com/faustomorales/mira/actions/workflows/ci.yaml/badge.svg) [![Documentation Status](https://readthedocs.org/projects/mira-python/badge/?version=latest)](https://mira-python.readthedocs.io/en/latest/?badge=latest)\n\nmira provides tooling for simple object detection projects. The package spans three areas of focus.\n\n- **Core** object detection abstractions for images and annotations\n- Access to **datasets** from common formats (e.g., VOC, COCO) and image sets (e.g., VOC 2012)\n- A common API to for **well-known models** (e.g., RetinaNet and FasterRCNN)\n\nCheck out [the docs](https://mira-python.readthedocs.io/en/latest/).\n\n## Installation\n\n```shell\npip install mira\n```\n',
    'author': 'Fausto Morales',
    'author_email': 'faustomorales@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/faustomorales/mira',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7.9,<3.11',
}


setup(**setup_kwargs)
